@@ -6,8 +6,8 @@
 #ifndef DETAILEDGRAPHICALOVERVIEW_H
 #define DETAILEDGRAPHICALOVERVIEW_H
 
-#include <QWidget>
 #include "kalziumelementproperty.h"
+#include <QWidget>
 
 class Element;
 
@@ -45,7 +45,7 @@ private:
     /**
      * the element whose data will be used
      */
-    Element *m_element;
+    Element *m_element = nullptr;
 
     /**
      * The background color.
@@ -53,7 +53,7 @@ private:
     QBrush m_backgroundBrush;
 
 protected:
-    void paintEvent(QPaintEvent*) override;
+    void paintEvent(QPaintEvent *) override;
 };
 
 #endif // DETAILEDGRAPHICALOVERVIEW_H
