@@ -7,20 +7,18 @@
 
 #include "kalziumutils.h"
 
-#include <QDebug>
-#include <QDialog>
+#include "kalzium_debug.h"
 #include <QDialogButtonBox>
 #include <QFont>
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <KConfigGroup>
+#include <kwidgetsaddons_version.h>
 #include <KGuiItem>
 #include <KHelpClient>
 #include <KLocalizedString>
 #include <KMessageBox>
 
-
 static const char HTML_HEADER[] =
     "<html>"
     "\n<head>"
@@ -45,71 +43,65 @@ static const char HTML_FOOTER[] =
     "\n</body>"
     "\n</html>";
 
-static const char XML_HEADER[] =
-    "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n";
+static const char XML_HEADER[] = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n";
 
-ElementListEntry::ElementListEntry(Element * element)
-        : QListWidgetItem()
+ElementListEntry::ElementListEntry(Element *element)
+    : QListWidgetItem()
 {
     m_atomicNum = element->dataAsVariant(ChemicalDataObject::atomicNumber).toInt();
-    m_name      = element->dataAsString(ChemicalDataObject::name);
-    m_element   = element;
+    m_name = element->dataAsString(ChemicalDataObject::name);
+    m_element = element;
 
     setText(m_name);
 }
 
-ElementListEntry::~ElementListEntry()
-{
-}
+ElementListEntry::~ElementListEntry() = default;
 
-PropertyListEntry::PropertyListEntry(const QString & name, ChemicalDataObject::BlueObelisk type)
-        : QListWidgetItem()
+PropertyListEntry::PropertyListEntry(const QString &name, ChemicalDataObject::BlueObelisk type)
+    : QListWidgetItem()
 {
     setText(name);
     m_type = type;
 }
 
-PropertyListEntry::~PropertyListEntry()
-{
-}
+PropertyListEntry::~PropertyListEntry() = default;
 
-ExportDialog::ExportDialog(QWidget * parent)
-        : QDialog(parent),m_outputStream(nullptr)
+ExportDialog::ExportDialog(QWidget *parent)
+    : QDialog(parent)
 {
-    qDebug() << "ExportDialog::ExportDialog";
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel|QDialogButtonBox::Help);
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    qCDebug(KALZIUM_LOG) << "ExportDialog::ExportDialog";
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
+    auto mainWidget = new QWidget(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
-    QPushButton *user1Button = new QPushButton;
+    auto user1Button = new QPushButton;
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ExportDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ExportDialog::reject);
     mainLayout->addWidget(buttonBox);
-    qDebug() << "ExportDialog: setButtons";
+    qCDebug(KALZIUM_LOG) << "ExportDialog: setButtons";
     ui.setupUi(mainWidget);
-    qDebug() << "ExportDialog: ui.setupUi(mainWidget)";
+    qCDebug(KALZIUM_LOG) << "ExportDialog: ui.setupUi(mainWidget)";
     KGuiItem::assign(user1Button, KGuiItem(i18n("OK")));
-    qDebug() << "ExportDialog: setButtonGuiItem(User1, KGuiItem(i18n(\"OK\")));";
+    qCDebug(KALZIUM_LOG) << "ExportDialog: setButtonGuiItem(User1, KGuiItem(i18n(\"OK\")));";
     ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);
-    qDebug() << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
+    qCDebug(KALZIUM_LOG) << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
 
     setWindowTitle(i18nc("@title:window", "Export Chemical Data"));
-    qDebug() << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
+    qCDebug(KALZIUM_LOG) << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
 
     populateElementList();
-    qDebug() << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
+    qCDebug(KALZIUM_LOG) << "ui.targetFile->setMode(KFile::File | KFile::Directory | KFile::LocalOnly);";
 
     ui.formatList->addItem(QStringLiteral(".html (formatted html document)"), "html");
     ui.formatList->addItem(QStringLiteral(".xml (raw element data)"), "xml");
     ui.formatList->addItem(QStringLiteral(".csv (comma-separated data)"), "csv");
-    qDebug() << "ui.formatList->addItem(...);";
+    qCDebug(KALZIUM_LOG) << "ui.formatList->addItem(...);";
 
     connect(user1Button, &QPushButton::clicked, this, &ExportDialog::slotOkClicked);
-    qDebug() << "connect(user1Button, SIGNAL(clicked()), this, SLOT(slotOkClicked()));";
+    qCDebug(KALZIUM_LOG) << "connect(user1Button, SIGNAL(clicked()), this, SLOT(slotOkClicked()));";
     connect(buttonBox, &QDialogButtonBox::helpRequested, this, &ExportDialog::slotHelpRequested);
-    qDebug() << "KHelpClient::invokeHelp(QString(), \"kalzium\");";
+    qCDebug(KALZIUM_LOG) << "KHelpClient::invokeHelp(QString(), \"kalzium\");";
 }
 
 ExportDialog::~ExportDialog()
@@ -120,8 +112,8 @@ ExportDialog::~ExportDialog()
 void ExportDialog::populateElementList()
 {
     // Add descriptive headers
-    QListWidgetItem *header1 = new QListWidgetItem(i18n("Elements"));
-    QListWidgetItem *header2 = new QListWidgetItem(i18n("Properties"));
+    auto header1 = new QListWidgetItem(i18n("Elements"));
+    auto header2 = new QListWidgetItem(i18n("Properties"));
     header1->setFlags(Qt::ItemIsEnabled);
     header2->setFlags(Qt::ItemIsEnabled);
     QFont font;
@@ -133,13 +125,13 @@ void ExportDialog::populateElementList()
 
     // Add elements
     foreach (Element *element, KalziumDataObject::instance()->ElementList) {
-        ElementListEntry *entry = new ElementListEntry(element);
+        auto entry = new ElementListEntry(element);
         ui.elementListWidget->addItem(entry);
     }
 
     ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Atomic Number"), ChemicalDataObject::atomicNumber));
     ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Symbol"), ChemicalDataObject::symbol));
-    //ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Name"), ChemicalDataObject::name));
+    // ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Name"), ChemicalDataObject::name));
     ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Mass"), ChemicalDataObject::mass));
     ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Exact Mass"), ChemicalDataObject::exactMass));
     ui.propertyListWidget->addItem(new PropertyListEntry(i18n("Ionization"), ChemicalDataObject::ionization));
@@ -161,7 +153,19 @@ void ExportDialog::slotOkClicked()
     }
     QFile outputFile(filename);
     if (outputFile.exists()) {
-        if (KMessageBox::questionYesNo(this, i18n("File already exists. Do you want to overwrite it?")) == KMessageBox::No) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(this,
+#else
+        if (KMessageBox::questionYesNo(this,
+#endif
+            i18n("File already exists. Do you want to overwrite it?"), QString(),
+            KStandardGuiItem::overwrite(),
+            KStandardGuiItem::cancel())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            == KMessageBox::SecondaryAction) {
+#else
+            == KMessageBox::No) {
+#endif
             return;
         }
     }
@@ -193,17 +197,10 @@ void ExportDialog::exportToHtml()
 {
     *m_outputStream << HTML_HEADER << "<table>\n";
     foreach (QListWidgetItem *element, ui.elementListWidget->selectedItems()) {
-        *m_outputStream << "<tr>\n<th colspan=\"2\">"
-        << ((ElementListEntry*)element)->m_element->dataAsString(ChemicalDataObject::name)
-        << "</th>\n</tr>\n";
+        *m_outputStream << "<tr>\n<th colspan=\"2\">" << ((ElementListEntry *)element)->m_element->dataAsString(ChemicalDataObject::name) << "</th>\n</tr>\n";
         foreach (QListWidgetItem *property, ui.propertyListWidget->selectedItems()) {
-            *m_outputStream << "<tr>\n<td class=\"property\">"
-            << ((PropertyListEntry*) property)->text()
-            << "</td>\n<td class=\"value\">"
-            << KalziumUtils::prettyUnit(
-                ((ElementListEntry*) element)->m_element,
-                ((PropertyListEntry*) property)->m_type)
-            << "</td>\n</tr>\n";
+            *m_outputStream << "<tr>\n<td class=\"property\">" << ((PropertyListEntry *)property)->text() << "</td>\n<td class=\"value\">"
+                            << KalziumUtils::prettyUnit(((ElementListEntry *)element)->m_element, ((PropertyListEntry *)property)->m_type) << "</td>\n</tr>\n";
         }
     }
     *m_outputStream << "</table>\n" << HTML_FOOTER;
@@ -213,17 +210,10 @@ void ExportDialog::exportToXml()
 {
     *m_outputStream << XML_HEADER << "<elements>\n";
     foreach (QListWidgetItem *element, ui.elementListWidget->selectedItems()) {
-        *m_outputStream << "  <element name=\""
-        << ((ElementListEntry*) element)->m_element->dataAsString(ChemicalDataObject::name)
-        << "\">\n";
+        *m_outputStream << "  <element name=\"" << ((ElementListEntry *)element)->m_element->dataAsString(ChemicalDataObject::name) << "\">\n";
         foreach (QListWidgetItem *property, ui.propertyListWidget->selectedItems()) {
-            *m_outputStream << "    <property name=\""
-            << ((PropertyListEntry*) property)->text()
-            << "\">"
-            << KalziumUtils::prettyUnit(
-                ((ElementListEntry*) element)->m_element,
-                ((PropertyListEntry*) property)->m_type)
-            << "</property>\n";
+            *m_outputStream << "    <property name=\"" << ((PropertyListEntry *)property)->text() << "\">"
+                            << KalziumUtils::prettyUnit(((ElementListEntry *)element)->m_element, ((PropertyListEntry *)property)->m_type) << "</property>\n";
         }
         *m_outputStream << "  </element>\n";
     }
@@ -234,21 +224,13 @@ void ExportDialog::exportToCsv()
 {
     *m_outputStream << "Name";
     foreach (QListWidgetItem *property, ui.propertyListWidget->selectedItems()) {
-        *m_outputStream << ", \""
-        << ((PropertyListEntry*) property)->text()
-        << "\"";
+        *m_outputStream << ", \"" << ((PropertyListEntry *)property)->text() << "\"";
     }
     *m_outputStream << "\n";
     foreach (QListWidgetItem *element, ui.elementListWidget->selectedItems()) {
-        *m_outputStream << "\""
-        << ((ElementListEntry*) element)->m_element->dataAsString(ChemicalDataObject::name)
-        << "\"";
+        *m_outputStream << "\"" << ((ElementListEntry *)element)->m_element->dataAsString(ChemicalDataObject::name) << "\"";
         foreach (QListWidgetItem *property, ui.propertyListWidget->selectedItems()) {
-            *m_outputStream << ", \""
-            << KalziumUtils::prettyUnit(
-                ((ElementListEntry*) element)->m_element,
-                ((PropertyListEntry*) property)->m_type)
-            << "\"";
+            *m_outputStream << ", \"" << KalziumUtils::prettyUnit(((ElementListEntry *)element)->m_element, ((PropertyListEntry *)property)->m_type) << "\"";
         }
         *m_outputStream << "\n";
     }
