@@ -13,14 +13,14 @@
 
 #include <prefs.h>
 
-KalziumElementProperty* KalziumElementProperty::instance()
+KalziumElementProperty *KalziumElementProperty::instance()
 {
     static KalziumElementProperty elementProperty;
     return &elementProperty;
 }
 
 KalziumElementProperty::KalziumElementProperty()
-        : m_mode(0)
+    : m_mode(0)
 {
     m_currentScheme = Prefs::colorschemebox();
 
@@ -33,9 +33,7 @@ KalziumElementProperty::KalziumElementProperty()
         m_mode = GRADIENTVALUE;
 }
 
-KalziumElementProperty::~KalziumElementProperty()
-{
-}
+KalziumElementProperty::~KalziumElementProperty() = default;
 
 bool KalziumElementProperty::isGradient()
 {
@@ -78,12 +76,12 @@ QStringList KalziumElementProperty::gradientList() const
     return customList;
 }
 
-KalziumSchemeType* KalziumElementProperty::scheme() const
+KalziumSchemeType *KalziumElementProperty::scheme() const
 {
     return KalziumSchemeTypeFactory::instance()->build(m_currentScheme);
 }
 
-KalziumGradientType* KalziumElementProperty::gradient() const
+KalziumGradientType *KalziumElementProperty::gradient() const
 {
     if (m_currentGradient == NOGRADIENT) {
         return KalziumGradientTypeFactory::instance()->build(NOGRADIENT);
@@ -131,21 +129,25 @@ QBrush KalziumElementProperty::getElementBrush(int el)
 
     // Hide filtered elements from search
     if (!KalziumDataObject::instance()->search()->matches(el) && KalziumDataObject::instance()->search()->isActive()) {
-        return QBrush(Qt::darkGray, Qt::Dense7Pattern);
+        return {Qt::darkGray, Qt::Dense7Pattern};
     }
 
-    //The iconic view is the 3rd view (0,1,2,...). Pixmaps don't make nice gradients.
-    if (m_currentScheme ==  2) {
-        elementBrush =  scheme()->elementBrush(el);
+    // The iconic view is the 3rd view (0,1,2,...). Pixmaps don't make nice gradients.
+    if (m_currentScheme == 2) {
+        elementBrush = scheme()->elementBrush(el);
     } else {
         // add a nice gradient
         QColor color = getElementColor(el);
         QLinearGradient grad(QPointF(0, 0), QPointF(0, 40));
-        grad.setColorAt(0,color);
+        grad.setColorAt(0, color);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         qreal h, s, v, a;
+#else
+        float h, s, v, a;
+#endif
         color.getHsvF(&h, &s, &v, &a);
-        color.setHsvF(h, s, v*0.7, a);
-        grad.setColorAt(1,color);
+        color.setHsvF(h, s, v * 0.7, a);
+        grad.setColorAt(1, color);
 
         elementBrush = QBrush(grad);
     }
@@ -167,11 +169,10 @@ QColor KalziumElementProperty::getBorderColor(int el) const
 
     // Transparent Borders don't make sens.
     if (getTextColor(el) == QColor(Qt::transparent)) {
-        return QColor(Qt::black);
+        return {Qt::black};
     }
 
     return getTextColor(el);
-
 }
 
 int KalziumElementProperty::getMode() const
@@ -188,16 +189,15 @@ QColor KalziumElementProperty::gradientBrushLogic(int el) const
     const double boiling = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::boilingpoint).toDouble();
 
     switch (m_currentGradient) {
-
     case SOMGradientType:
         if (m_slider < melting) {
-            //the element is solid
+            // the element is solid
             gradientColor = Prefs::color_solid();
         } else if ((m_slider > melting) && (m_slider < boiling)) {
-            //the element is liquid
+            // the element is liquid
             gradientColor = Prefs::color_liquid();
         } else if ((m_slider >= boiling) && (boiling > 0.0)) {
-            //the element is vaporous
+            // the element is vaporous
             gradientColor = Prefs::color_vapor();
         } else {
             gradientColor = Qt::lightGray;
@@ -217,7 +217,7 @@ QColor KalziumElementProperty::gradientBrushLogic(int el) const
         break;
     }
 
-    if (!isActiv && gradientValue != -1) { //FIXME No magic number... Defined in KalziumGradientFactory
+    if (!isActiv && gradientValue != -1) { // FIXME No magic number... Defined in KalziumGradientFactory
         gradientColor = Qt::transparent;
     } else {
         const double coeff = gradient()->elementCoeff(el);
@@ -225,4 +225,3 @@ QColor KalziumElementProperty::gradientBrushLogic(int el) const
     }
     return gradientColor;
 }
-
