@@ -41,7 +41,7 @@ public:
     /**
      * Destructor.
      */
-    ~NumerationItem();
+    ~NumerationItem() override;
 
     /**
      * @return the bounding rectangle of the element item.
@@ -87,7 +87,6 @@ private:
      * The color of the element.
      */
     QColor m_color;
-
 };
 
 #endif // NUMERATIONITEM_H
