@@ -12,21 +12,18 @@
 #include <KLocalizedString>
 
 #include "prefs.h"
-#include "kalziumschemetype.h"
 #include "psetables.h"
 
-TableInfoWidget::TableInfoWidget(QWidget *parent) : QWidget(parent)
+TableInfoWidget::TableInfoWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_tableType(new QLabel(QStringLiteral("test"), this))
 {
-    m_tableType = new QLabel(QStringLiteral("test"), this);
 
-    QHBoxLayout * la = new QHBoxLayout(this);
+    auto la = new QHBoxLayout(this);
     la->addWidget(m_tableType);
-    setLayout(la);
 }
 
 void TableInfoWidget::setTableType(int type)
 {
     m_tableType->setText(pseTables::instance()->getTabletype(type)->description());
 }
-
-
